import {
  select,
  csv,
  scaleLinear,
  scaleBand,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleOrdinal
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Cereals: Sugar vs Ratings';
  
  const cValue = d => d.name;
  const color = scaleOrdinal(d3.schemeCategory10);
  
  const xValue = d => d.sugars;
  const xAxisLabel = 'Sugar';
  
  const yValue = d => d.rating;
  const circleRadius = 10;
  const yAxisLabel = 'rating';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(30);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
  
  // draw legend
  var legend = svg.selectAll(".legend")
  	  .domain(extent(data, color))	
      //.data(color.domain())
    .enter().append("g")
      .attr("class", "legend")
      .attr("transform", (d, i) => `translate(-40,${(i + 8.5) * 20})`);

  // draw legend colored rectangles
  legend.append("rect")
      .attr("x", width - 18)
      .attr("width", 18)
      .attr("height", 18)
      .style("fill", color);

  // draw legend text
  legend.append("text")
      .attr("x", width - 24)
      .attr("y", 9)
      .attr("dy", ".35em")
      .style("text-anchor", "end")
      .text(function(d) { return d;})
};

csv('data.csv')
  .then(data => {
    data.forEach(d => {
      d.calories = +d.calories; 
      d.protein = +d.protein;
      d.sugars = +d.sugars;
      d.carbo = +d.carbo;
      d.sodium = +d.sodium;
      d.fibre = +d.fibre;
      d.fat = +d.fat;
      d.rating = +d.rating;
    });
 //console.log(data)
    render(data);
  });